@@ -1,8 +1,13 @@
-# GerminaR ----------------------------------------------------------------
+# -------------------------------------------------------------------------
+# GerminaR-----------------------------------------------------------------
+# -------------------------------------------------------------------------
+#> open https://flavjack.github.io/GerminaR/
+#> open https://flavjack.shinyapps.io/germinaquant/
+#> author .: Flavio Lozano-Isla (lozanoisla.com)
+#> date .: 2020-10-18
 # -------------------------------------------------------------------------
 
-# open https://flavjack.shinyapps.io/germinaquant/
-
+# -------------------------------------------------------------------------
 # packages ----------------------------------------------------------------
 # -------------------------------------------------------------------------
 
@@ -50,14 +55,14 @@ shinyUI(dashboardPage(skin = "green",
       ),
       
       tags$head(includeHTML(("www/analytics.html"))),
-      tags$head(tags$link(rel="shortcut icon", href="https://raw.githubusercontent.com/Flavjack/GerminaR/master/inst/GerminaQuant/www/favicon/android-chrome-256x256.png")),
+      tags$head(tags$link(rel="shortcut icon", href="https://flavjack.github.io/GerminaR/reference/figures/logo.png")),
 
       meta() %>%
         meta_social(
           title = "GerminaR",
           description = "Indices and Graphics for Assess Seed Germination Process",
           url = "https://flavjack.shinyapps.io/germinaquant/",
-          image = "https://raw.githubusercontent.com/Flavjack/GerminaR/master/inst/GerminaQuant/www/favicon/android-chrome-256x256.png",
+          image = "https://flavjack.github.io/GerminaR/reference/figures/logo.png",
           image_alt = "GerminaR"
         ), 
 
@@ -94,13 +99,13 @@ shinyUI(dashboardPage(skin = "green",
                   <div id=footer style="width:100%; margin:auto;">
                   <div style="display:inline-block; width:49%">
                   <p style="text-align:center">
-                  <a target="_blank" href="https://CRAN.R-project.org/package=GerminaR"><img src="https://flavjack.github.io/germinaquant/files/icon.png" style="height:80px" title="R cran" alt="GerminaR"></a> 
+                  <a target="_blank" href="https://CRAN.R-project.org/package=GerminaR"><img src="https://flavjack.github.io/GerminaR/reference/figures/logo.png" style="height:80px" title="R cran" alt="GerminaR"></a> 
                   <span style="display:block;"><small>GerminaR</small></span>
                   </p></div>
                   
                   <div style="display:inline-block; width:49%">
                   <p style="text-align:center">
-                  <a target="_blank" href="https://flavjack.shinyapps.io/germinaquant/"><img src="https://raw.githubusercontent.com/Flavjack/GerminaR/master/inst/GerminaQuant/www/germinaquant.png" style="height:70px" title="GerminaQuant" alt="GerminaQuant for R"></a>
+                  <a target="_blank" href="https://flavjack.shinyapps.io/germinaquant/"><img src="https://flavjack.github.io/GerminaR/reference/figures/germinaquant.png" style="height:70px" title="GerminaQuant" alt="GerminaQuant for R"></a>
                   <span style="display:block;"><small>GerminaQuant</small></span>
                   </p></div>
 
@@ -164,8 +169,8 @@ shinyUI(dashboardPage(skin = "green",
                       
                       <div style="display:inline-block; width:49%">
                       <p style="text-align:center">
-                      <a target="_blank" href="https://flavjack.github.io/germinaquant/"><img src="https://bookdown.org/yihui/bookdown/images/logo.png" style="height:70px" title="PLEX" alt="PLEX"></a> 
-                      <span style="display:block;"><small>Manual</small></span>
+                      <a target="_blank" href="https://flavjack.github.io/GerminaR/"><img src="https://pkgdown.r-lib.org/reference/figures/logo.png" style="height:75px" title="GerminaR" alt="GerminaR"></a> 
+                      <span style="display:block;"><small>Project</small></span>
                       </p></div>
                       
                       </div>
